@@ -1,11 +1,13 @@
 #ifdef CHASTE_CVODE{% with %}{% set is_cvode = True %}
 {% include "Shared/cpp/header_comments" %}
 {% include "Shared/cpp/includes" %}
+{% include "Shared/cpp/lookup_tables" %}
 {% include "Shared/cpp/UseCellMLDefaultStimulus" %}
 {% include "Cvode/cpp/GetIntracellularCalciumConcentration" %}
 {%- include "Shared/cpp/constructor_declaration" %}
 {% include "Shared/cpp/constructor_body" %}
 {% include "Shared/cpp/destructor" %}
+{% include "Shared/cpp/GetLookupTableCollection" %}
 {% include "Cvode/cpp/VerifyStateVariables" %}
 {% include "Cvode/cpp/GetIIonic" %}
 {% include "Shared/cpp/EvaluateYDerivatives" %}
